@@ -11,3 +11,11 @@ from .continuous_continuous import (
     mat_corr_nan,
     mat_corr_subtyped,
 )
+from .continuous_continuous_cmap import (
+    fast_cov,
+    nan_fast_cov,
+    fast_corr,
+    nan_fast_corr,
+    fast_spearman,
+    nan_fast_spearman,
+)
